package com.datacloudsec.scan.service.impl;

import com.datacloudsec.annotations.Transactional;
import com.datacloudsec.engine.dlp.AbsDlpDb;
import com.datacloudsec.engine.dlp.Engine;
import com.datacloudsec.engine.dlp.handler.ConsoleHandler;
import com.datacloudsec.engine.dlp.handler.IHandler;
import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.dao.DeviceMapper;
import com.datacloudsec.scan.dao.DlpProfilesMapper;
import com.datacloudsec.scan.dao.DlpscanMapper;
import com.datacloudsec.scan.dao.EngineMapper;
import com.datacloudsec.scan.entity.LicCmp;
import com.datacloudsec.scan.entity.Task;
import com.datacloudsec.scan.entity.User;
import com.datacloudsec.scan.service.IDlpscan;
import com.datacloudsec.scan.service.IReport;
import com.datacloudsec.scan.tasks.InitSystemTask;
import com.datacloudsec.scan.tasks.scheduler.job.AlermJob;
import com.datacloudsec.utils.ComonZipUtil;
import com.datacloudsec.utils.DataRule;
import com.datacloudsec.utils.EntryResult;
import com.datacloudsec.utils.FtpUtil;
import com.datacloudsec.utils.IPUtil;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.JsonUtil;
import com.datacloudsec.utils.ObjectUtil;
import com.datacloudsec.utils.SerializeUtil;
import java.io.File;
import java.nio.charset.Charset;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.UUID;
import javax.servlet.http.HttpSession;
import org.apache.commons.io.FileUtils;
import org.apache.commons.io.IOUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/DlpscanService.class */
public class DlpscanService extends TaskBaseService implements IDlpscan {
    private DlpProfilesMapper dlpProfilesMapper = (DlpProfilesMapper) InstanceUtil.newDaoInstance(DlpProfilesMapper.class);
    private DeviceMapper deviceMapper = (DeviceMapper) InstanceUtil.newDaoInstance(DeviceMapper.class);
    private static Logger LOG = Logger.getLogger(DlpscanService.class);
    private static DlpscanMapper dlpscanMapper = (DlpscanMapper) InstanceUtil.newDaoInstance(DlpscanMapper.class);
    private static EngineMapper engMapper = (EngineMapper) InstanceUtil.newDaoInstance(EngineMapper.class);

    @Transactional
    public int delete(HttpSession session, Integer taskid, Integer version) throws Exception {
        int n = dlpscanMapper.queryTaskDevCount((String) null, (Integer) null, 1, taskid).intValue();
        if (n > 0) {
            throw new UEException("该任务中有" + n + "个资产正在扫描，请先停止该任务中所有正在扫描的资产再删除！");
        }
        stopTimer(session, taskid);
        List<Map<String, Object>> systems = dlpscanMapper.getSystemsByTid(taskid);
        for (Map<String, Object> sys : systems) {
            delDlpRes(ObjectUtil.getString(sys.get("tracker"), ""));
        }
        dlpscanMapper.delDlp(taskid);
        dlpscanMapper.delTaskDevByTid(taskid);
        Integer rcount = Integer.valueOf(dlpscanMapper.delete(taskid, version, DataRule.getRuleWhere(session, "t_task")));
        if (rcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
        return rcount.intValue();
    }

    @Transactional
    public Integer insert(HttpSession session, String name, String profile, String desct, Integer type, String alarmMethod, Integer alarmType, String alarmTime, String mailAddr, String smsAddr, String ip, String periodTime, String emailcheck, String smscheck, Integer val1, Integer dlpType, String confContent) throws Exception {
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        if (!cmp.contains("dlpscan")) {
            throw new UEException("敏感信息扫描任务未授权");
        }
        LicCmp licCmp = getLicCp(cmp, "dlpscan");
        if (InitSystemTask.licenseApp.valudate(licCmp.getAuthDay()) != 0) {
            throw new UEException("敏感信息扫描任务授权已过期");
        }
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        try {
            Integer count = dlpscanMapper.getTaskCountByName(name, 9, uid, (Integer) null);
            if (count != null && count.intValue() > 0) {
                throw new UEException("任务名称已存在！");
            }
        } catch (Exception e) {
            Integer count2 = dlpscanMapper.getTcountForOthers(name, 9, (Integer) null);
            if (count2 != null && count2.intValue() > 0) {
                throw new UEException("任务名称已存在！");
            }
        }
        Integer taskid = add(null, name, desct, type, alarmMethod, alarmType, alarmTime, mailAddr, smsAddr, ip, periodTime, emailcheck, smscheck, null, 9, val1, profile, session, dlpType, confContent);
        if (dlpType.intValue() == 0) {
            if (type.intValue() == 1) {
                List<Map<String, Object>> resList = dlpscanMapper.getSystemsByTid(taskid);
                for (Map<String, Object> res : resList) {
                    try {
                        start(ObjectUtil.getInt(res.get("deviceid")));
                    } catch (Exception e2) {
                        LOG.error("扫描失败（" + ObjectUtil.getString(res.get("ip"), "") + "）", e2);
                    }
                }
            }
            startTimer(taskid, type, periodTime, alarmType, alarmMethod, alarmTime);
        } else {
            Map<String, Object> profiles = this.dlpProfilesMapper.getProfilesByPro(profile);
            if (type.intValue() == 1 && !"win_agent".equalsIgnoreCase(ObjectUtil.getString(profiles.get("scantype"), ""))) {
                List<Map<String, Object>> resList2 = dlpscanMapper.getSystemsByTid(taskid);
                for (Map<String, Object> res2 : resList2) {
                    try {
                        start(ObjectUtil.getInt(res2.get("deviceid")));
                    } catch (Exception e3) {
                        LOG.error("扫描失败（" + ObjectUtil.getString(res2.get("ip"), "") + "）", e3);
                    }
                }
            }
            if (!"win_agent".equalsIgnoreCase(ObjectUtil.getString(profiles.get("scantype"), ""))) {
                startTimer(taskid, type, periodTime, alarmType, alarmMethod, alarmTime);
            }
        }
        return taskid;
    }

    private void startLinuxScan(String ip, String tracker, String name, Integer deviceid, String profilename) throws Exception {
        Map<String, Object> device = dlpscanMapper.getTaskDevById(deviceid);
        Map<String, Object> taskwebmap = new HashMap<>();
        taskwebmap.put("devid", deviceid);
        taskwebmap.put("status", 1);
        taskwebmap.put("scanCount", Integer.valueOf(ObjectUtil.getInt(device.get("scanCount"), 0) + 1));
        taskwebmap.put("progress", 0);
        dlpscanMapper.updateTaskDevice(taskwebmap);
        if (ObjectUtil.getInt(taskwebmap.get("status")).intValue() == 3) {
            return;
        }
        Process process = null;
        try {
            try {
                Process process2 = Runtime.getRuntime().exec(new String[]{"/bin/sh", "-c", "sudo /opt/data/workdir/conf/agentless-unix.pl " + profilename + " " + ip + " " + tracker + " " + deviceid + " " + name + " &"});
                if (process2.waitFor() != 0) {
                    String error = IOUtils.toString(process2.getErrorStream(), Charset.defaultCharset().toString());
                    LOG.error(error);
                    taskwebmap.put("status", 3);
                    taskwebmap.put("error", error);
                    dlpscanMapper.updateTaskDevice(taskwebmap);
                    throw new UEException("扫描失败！");
                }
                String err = IOUtils.toString(process2.getErrorStream(), Charset.defaultCharset().toString());
                if (StringUtils.isNotBlank(err)) {
                    LOG.error(err);
                    taskwebmap.put("status", 3);
                    taskwebmap.put("error", err);
                    dlpscanMapper.updateTaskDevice(taskwebmap);
                    throw new UEException("扫描失败！");
                }
                if (process2 != null) {
                    try {
                        process2.destroy();
                    } catch (Exception e) {
                    }
                }
            } catch (Exception e2) {
                taskwebmap.put("status", 3);
                taskwebmap.put("error", "扫描错误");
                dlpscanMapper.updateTaskDevice(taskwebmap);
                throw e2;
            }
        } catch (Throwable th) {
            if (0 != 0) {
                try {
                    process.destroy();
                } catch (Exception e3) {
                }
            }
            throw th;
        }
    }

    private Integer add(Integer id, String name, String desct, Integer type, String alarmMethod, Integer alarmType, String alarmTime, String mailAddr, String smsAddr, String ip, String periodTime, String emailcheck, String smscheck, Integer version, Integer taskType, Integer val1, String profile, HttpSession session, Integer dlpType, String confContent) throws Exception {
        String validip;
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        LicCmp licCmp = getLicCp(cmp, "dlpscan");
        User user = (User) session.getAttribute("userInfo");
        int maxdevice = licCmp.getMaxdevice();
        String rule = DataRule.getRuleWhere(session, "t_task");
        Task task = new Task();
        task.setName(name);
        task.setDesct(desct);
        task.setType(type);
        task.setAlarmMethod(alarmMethod);
        task.setAlarmType(alarmType);
        task.setAlarmTime(alarmTime);
        task.setMailAddr(emailcheck);
        task.setSmsAddr(smscheck);
        task.setPeriodTime(periodTime);
        if (user != null) {
            task.setUid(user.getId());
        }
        task.setTaskType(taskType);
        task.setVersion(version);
        task.setRule(rule);
        task.setVal1(val1);
        task.setVal2(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
        task.setConfContent(confContent);
        if (dlpType != null) {
            task.setSysId(dlpType);
        }
        task.setWarningType((String) null);
        if (id != null) {
            task.setId(id);
        }
        if (id == null) {
            List<Map<String, Object>> devListMap = (List) JsonUtil.MAPPER_ESCAPE_HTML.readValue(ip, ArrayList.class);
            int devIpCount = 0;
            for (Map<String, Object> devMap : devListMap) {
                Map<String, Object> map = this.deviceMapper.getDevById(ObjectUtil.getInt(ObjectUtil.getString(devMap.get("id"), "").split("\\|")[0]));
                if (map != null) {
                    validip = ObjectUtil.getString(map.get("ip"), "");
                } else {
                    validip = ObjectUtil.getString(devMap.get("name"), "");
                }
                if (user != null && StringUtils.isNotBlank(user.getIps()) && !IPUtil.ipVaild(validip, user.getIps())) {
                    throw new UEException("IP【" + validip + "】不在扫描范围内，可联系管理员授权扫描此IP");
                }
                devIpCount++;
            }
            if (maxdevice > 0 && dlpscanMapper.getCountByType("12") + devIpCount > maxdevice) {
                throw new UEException("当前资产数已达授权上限[" + maxdevice + "]");
            }
            dlpscanMapper.insert(task);
            for (Map<? extends String, ? extends Object> devMap2 : devListMap) {
                String[] idarr = ObjectUtil.getString(devMap2.get("id"), "").split("\\|");
                Map<String, Object> map2 = this.deviceMapper.getDevById(ObjectUtil.getInt(idarr[0]));
                if (map2 != null) {
                    map2.put("type", 12);
                    map2.put("ip", ObjectUtil.getString(devMap2.get("name"), ""));
                    if (dlpType.intValue() == 0) {
                        Map<String, Object> confMap = (Map) EntryResult.parseEntryMap((List) ((Map) JsonUtil.MAPPER.readValue(ObjectUtil.getString(map2.get("confContent"), ""), Map.class)).get(ReportService.REPORT_STATE_FAILED), "db").get(idarr[2]);
                        confMap.putAll(devMap2);
                        map2.put("confContent", JsonUtil.MAPPER.writeValueAsString(confMap));
                    } else {
                        map2.put("confContent", ObjectUtil.getString(map2.get("authContent"), ""));
                    }
                    map2.put("taskId", task.getId());
                    dlpscanMapper.insertTaskDevice(map2);
                    if (dlpType.intValue() == 0) {
                        dlpscanMapper.insertDlp(name, "", "", ObjectUtil.getString(devMap2.get("name"), ""), task.getId(), ObjectUtil.getInt(map2.get("id")), UUID.randomUUID().toString().replace("-", ""), user.getId());
                    } else {
                        Map<String, Object> profileMap = this.dlpProfilesMapper.getProfilesByPro(profile);
                        dlpscanMapper.insertDlp(name, profile, ObjectUtil.getString(profileMap.get("scantype"), ""), ObjectUtil.getString(devMap2.get("name"), ""), task.getId(), ObjectUtil.getInt(map2.get("id")), UUID.randomUUID().toString().replace("-", ""), user.getId());
                    }
                }
            }
        } else {
            Integer rcount = dlpscanMapper.update(task);
            if (rcount != null && rcount.intValue() == 0) {
                throw new UEException("数据已被修改或删除，请刷新页面或返回");
            }
        }
        if (user != null) {
            if (StringUtils.isNotBlank(mailAddr)) {
                dlpscanMapper.delEmail(user.getId());
                String[] mail = mailAddr.split(",");
                for (String ml : mail) {
                    dlpscanMapper.insertEmail(ml, user.getId());
                }
            }
            if (StringUtils.isNotBlank(smsAddr)) {
                dlpscanMapper.delPhone(user.getId());
                String[] sms = smsAddr.split(",");
                for (String s : sms) {
                    dlpscanMapper.insertPhone(s, user.getId());
                }
            }
        }
        return task.getId();
    }

    public int getNameCount(String scan) throws Exception {
        return dlpscanMapper.getNameCount(scan);
    }

    public Map<String, Object> getDlpByTid(Integer taskid) throws Exception {
        return dlpscanMapper.getDlpByTid(taskid);
    }

    public List<Map<String, Object>> getProfiles() throws Exception {
        return dlpscanMapper.getProfiles();
    }

    public void update(HttpSession session, Integer id, String name, String profile, String desct, Integer type, String alarmMethod, Integer alarmType, String alarmTime, String mailAddr, String smsAddr, String ip, String periodTime, String emailcheck, String smscheck, Integer val1, Integer version, Integer dlpType, String confContent) throws Exception {
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = dlpscanMapper.getTaskCountByName(name, 9, uid, id);
        if (count != null && count.intValue() > 0) {
            throw new UEException("任务名称已存在！");
        }
        add(id, name, desct, type, alarmMethod, alarmType, alarmTime, mailAddr, smsAddr, null, periodTime, emailcheck, smscheck, version, 9, val1, profile, session, dlpType, confContent);
        Map<String, Object> profileMap = this.dlpProfilesMapper.getProfilesByPro(profile);
        if (dlpType.intValue() == 1) {
            String scantype = ObjectUtil.getString(profileMap.get("scantype"), "");
            dlpscanMapper.updDlp(id, name, profile, scantype, (String) null, uid);
        }
        stopTimer(session, id);
        if (alarmType.intValue() == 2 || type.intValue() == 2) {
            startTimer(id, type, periodTime, alarmType, alarmMethod, alarmTime);
        }
    }

    public List<Map<String, Object>> getDevDetailByTid(Integer id) throws Exception {
        return dlpscanMapper.getDevDetailByTid(id);
    }

    public List<Map<String, Object>> getResByTracker(String tracker) throws Exception {
        return dlpscanMapper.getResByTracker(tracker);
    }

    @Transactional
    public void manualAdd(HttpSession session, String ip, Integer taskId) throws Exception {
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        LicCmp licCmp = getLicCp(cmp, "dlpscan");
        int maxdevice = licCmp.getMaxdevice();
        if (maxdevice > 0 && dlpscanMapper.getCountByType("12") + 1 > maxdevice) {
            throw new UEException("当前资产数已达授权上限[" + maxdevice + "]");
        }
        Task task = dlpscanMapper.getTaskById(taskId);
        User user = (User) session.getAttribute("userInfo");
        Map<String, Object> web = new HashMap<>();
        web.put("name", ip);
        web.put("ip", ip);
        web.put("type", 12);
        web.put("taskId", taskId);
        web.put("regionCid", user.getRegionCid());
        web.put("regionSid", Integer.valueOf(user.getRegionSid() == null ? 110000 : user.getRegionSid().intValue()));
        dlpscanMapper.insertTaskDevice(web);
        Map<String, Object> dlpsys = dlpscanMapper.getDlpByTid(taskId);
        dlpscanMapper.insertDlp(task.getName(), ObjectUtil.getString(dlpsys.get("profile"), ""), ObjectUtil.getString(dlpsys.get("scantype"), ""), ip, task.getId(), ObjectUtil.getInt(web.get("id")), UUID.randomUUID().toString().replace("-", ""), user.getId());
        if (task != null && task.getType().intValue() == 1) {
            try {
                start(ObjectUtil.getInt(web.get("id")));
            } catch (Exception e) {
                LOG.error("", e);
            }
        }
    }

    /* JADX WARN: Type inference failed for: r0v48, types: [com.datacloudsec.scan.service.impl.DlpscanService$1] */
    public void start(Integer devid) throws Exception {
        final Map<String, Object> device = dlpscanMapper.getTaskDevById(devid);
        if (device == null) {
            throw new UEException("此任务已被其它用户删除！");
        }
        Task task = dlpscanMapper.getTaskBydevId(devid);
        int status = ObjectUtil.getInt(device.get("status"), 1);
        if (status != 1) {
            final Map<String, Object> dlpSystems = dlpscanMapper.getSystemsBydid(devid);
            if (task.getSysId().intValue() == 0) {
                String confStr = ObjectUtil.getString(device.get("confContent"), "");
                if (StringUtils.isBlank(task.getConfContent()) || StringUtils.isBlank(confStr)) {
                    throw new UEException("无关键字");
                }
                Map<String, Object> taskConf = (Map) JsonUtil.MAPPER.readValue(task.getConfContent(), Map.class);
                final Map<String, Object> confContent = (Map) JsonUtil.MAPPER.readValue(confStr, Map.class);
                final String[] ip = ObjectUtil.getString(device.get("ip"), "").split(":");
                final String[] keywords = "".equals(ObjectUtil.getString(taskConf.get("keywords"), "")) ? null : ObjectUtil.getString(taskConf.get("keywords"), "").split("\n");
                final String[] regex = "".equals(ObjectUtil.getString(taskConf.get("regex"), "")) ? null : ObjectUtil.getString(taskConf.get("regex"), "").split("\n");
                new Thread() { // from class: com.datacloudsec.scan.service.impl.DlpscanService.1
                    @Override // java.lang.Thread, java.lang.Runnable
                    public void run() {
                        try {
                            new Engine(new DlpscanHandler(device, ObjectUtil.getString(dlpSystems.get("tracker"), "")), keywords, regex).scan(AbsDlpDb.createDb(ObjectUtil.getString(confContent.get("db"), ""), ip[0].trim(), ObjectUtil.getInt(ip[1].trim()).intValue(), ObjectUtil.getString(confContent.get("username"), ""), ObjectUtil.getString(confContent.get("password"), ""), ObjectUtil.getInt(confContent.get("connect_type"), 0), ObjectUtil.getInt(confContent.get("role"), 0), ObjectUtil.getBoolean(confContent.get("useSsl"))), "".equals(ObjectUtil.getString(confContent.get("dbs"), "")) ? null : ObjectUtil.getString(confContent.get("dbs"), "").split("\n"), ObjectUtil.getInt(confContent.get("ignore_tables"), 0), "".equals(ObjectUtil.getString(confContent.get("tables"), "")) ? null : ObjectUtil.getString(confContent.get("tables"), "").split("\n"), ObjectUtil.getInt(confContent.get("ignore_columns"), 0), "".equals(ObjectUtil.getString(confContent.get("columns"), "")) ? null : ObjectUtil.getString(confContent.get("columns"), "").split("\n"));
                        } catch (Exception e) {
                            DlpscanService.LOG.error("", e);
                        }
                    }
                }.start();
                return;
            }
            startLinuxScan(ObjectUtil.getString(dlpSystems.get("ip"), ""), ObjectUtil.getString(dlpSystems.get("tracker"), ""), ObjectUtil.getString(dlpSystems.get("scan"), ""), ObjectUtil.getInt(dlpSystems.get("deviceid")), ObjectUtil.getString(dlpSystems.get("profile"), ""));
        }
    }

    public void stop(Integer devid) throws Exception {
        Task task = dlpscanMapper.getTaskBydevId(devid);
        if (task.getSysId().intValue() == 0) {
            throw new UEException("数据库敏感信息无需停止！");
        }
        Map<String, Object> dev = dlpscanMapper.getTaskDevById(devid);
        if (dev == null) {
            throw new UEException("此任务已被其它用户删除！");
        }
        int status = ObjectUtil.getInt(dev.get("status"), 0);
        if (status == 1) {
            Map<String, Object> systems = dlpscanMapper.getSystemsBydid(devid);
            Map<String, Object> taskwebmap = new HashMap<>();
            taskwebmap.put("progress", 0);
            taskwebmap.put("devid", devid);
            taskwebmap.put("status", 2);
            dlpscanMapper.updateTaskDevice(taskwebmap);
            Process process = null;
            try {
                try {
                    Process process2 = Runtime.getRuntime().exec(new String[]{"/bin/sh", "-c", "sudo kill -USR2 " + ObjectUtil.getString(systems.get("pid"), "") + " &"});
                    if (process2.waitFor() != 0) {
                        String error = IOUtils.toString(process2.getErrorStream(), Charset.defaultCharset().toString());
                        LOG.error(error);
                        taskwebmap.put("status", 3);
                        dlpscanMapper.updateTaskDevice(taskwebmap);
                        throw new UEException("扫描失败！");
                    }
                    String err = IOUtils.toString(process2.getErrorStream(), Charset.defaultCharset().toString());
                    if (StringUtils.isNotBlank(err)) {
                        LOG.error(err);
                        taskwebmap.put("status", 3);
                        dlpscanMapper.updateTaskDevice(taskwebmap);
                        throw new UEException("扫描失败！");
                    }
                    if (process2 != null) {
                        try {
                            process2.destroy();
                        } catch (Exception e) {
                        }
                    }
                } catch (Exception e2) {
                    throw e2;
                }
            } catch (Throwable th) {
                if (0 != 0) {
                    try {
                        process.destroy();
                    } catch (Exception e3) {
                    }
                }
                throw th;
            }
        }
    }

    public void startScanTask(Integer taskId) throws Exception {
        List<Map<String, Object>> taskDevList = dlpscanMapper.getTaskDevByTid(taskId);
        if (taskDevList == null) {
            throw new UEException("此任务已被其它用户删除！");
        }
        for (Map<String, Object> dev : taskDevList) {
            if (1 != ObjectUtil.getInt(dev.get("status")).intValue()) {
                Integer devid = ObjectUtil.getInt(dev.get("id"));
                try {
                    start(devid);
                } catch (Exception e) {
                    LOG.error("手动扫描出错", e);
                }
            }
        }
    }

    public void stopScanTask(Integer taskId) throws Exception {
        Task task = dlpscanMapper.getTaskById(taskId);
        if (task.getSysId().intValue() == 0) {
            throw new UEException("数据库敏感信息无需停止！");
        }
        List<Map<String, Object>> taskDevList = dlpscanMapper.getTaskDevByTid(taskId);
        if (taskDevList == null) {
            throw new UEException("此任务已被其它用户删除！");
        }
        for (Map<String, Object> dev : taskDevList) {
            Integer devid = ObjectUtil.getInt(dev.get("id"));
            try {
                stop(devid);
            } catch (Exception e) {
                if (e instanceof UEException) {
                    throw e;
                }
                throw new UEException("停止出错", e);
            }
        }
        Task t = dlpscanMapper.getTaskById(taskId);
        if (ObjectUtil.getInt(t.getAlarmType(), 0) == 1) {
            AlermJob.alermTask(taskId);
        }
    }

    public void delDev(Integer devId) throws Exception {
        Map<String, Object> webMap = dlpscanMapper.getTaskDevById(devId);
        if (1 == ObjectUtil.getInt(webMap.get("status")).intValue()) {
            throw new UEException("正在扫描，请先停止后再删除！");
        }
        Map<String, Object> sys = dlpscanMapper.getSystemsBydid(devId);
        delDlpRes(ObjectUtil.getString(sys.get("tracker"), ""));
        dlpscanMapper.delDlpBydevid(devId);
        dlpscanMapper.delTaskDevById(devId);
    }

    public void addDev(HttpSession session, String devIds, Integer taskId) throws Exception {
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        LicCmp licCmp = getLicCp(cmp, "dlpscan");
        int maxdevice = licCmp.getMaxdevice();
        String[] devIdArr = devIds.split(",");
        int devIpCount = 0;
        for (String devid : devIdArr) {
            Map<String, Object> map = this.deviceMapper.getDevById(ObjectUtil.getInt(devid));
            if (map != null && this.deviceMapper.getDevRecordByIp(ObjectUtil.getString(map.get("ip"), ""), "dlpscan").intValue() == 0) {
                devIpCount++;
            }
        }
        if (maxdevice > 0 && this.deviceMapper.getDevRecord("dlpscan").intValue() + devIpCount > maxdevice) {
            throw new UEException("当前资产数已达授权上限[" + maxdevice + "]");
        }
        List<Integer> devices = new ArrayList<>();
        Task task = dlpscanMapper.getTaskById(taskId);
        User user = (User) session.getAttribute("userInfo");
        for (String devid2 : devIdArr) {
            Map<String, Object> devMap = this.deviceMapper.getDevById(ObjectUtil.getInt(devid2));
            devMap.put("taskId", taskId);
            devMap.put("type", 12);
            dlpscanMapper.insertTaskDevice(devMap);
            devices.add(ObjectUtil.getInt(devMap.get("id")));
            Map<String, Object> dlpsys = dlpscanMapper.getDlpByTid(taskId);
            dlpscanMapper.insertDlp(task.getName(), ObjectUtil.getString(dlpsys.get("profile"), ""), ObjectUtil.getString(dlpsys.get("scantype"), ""), ObjectUtil.getString(devMap.get("ip"), ""), task.getId(), ObjectUtil.getInt(devMap.get("id")), UUID.randomUUID().toString().replace("-", ""), user.getId());
        }
        for (Integer devid3 : devices) {
            Map<String, Object> devMap2 = dlpscanMapper.getTaskDevById(devid3);
            if (task != null && task.getType().intValue() == 1) {
                try {
                    start(ObjectUtil.getInt(devMap2.get("id")));
                } catch (Exception e) {
                    LOG.error("扫描错误", e);
                }
            }
        }
    }

    public int markBugErr(Integer id, Integer status) throws Exception {
        return dlpscanMapper.markBugErr(id, status);
    }

    public File backup(Task t) throws Exception {
        File dir = new File(Constant.TEMP_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
        if (!dir.exists()) {
            dir.mkdirs();
        }
        File f = new File(Constant.TEMP_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
        try {
            SerializeUtil.serializeObj(new File(dir, "task.backup"), t);
            List<Map<String, Object>> devList = dlpscanMapper.getTaskDevByTid(t.getId());
            for (Map<String, Object> dev : devList) {
                Integer devid = ObjectUtil.getInt(dev.get("id"));
                File devDir = new File(dir, new StringBuilder().append(devid).toString());
                if (!devDir.exists()) {
                    devDir.mkdirs();
                }
                SerializeUtil.serializeObj(new File(devDir, "dev.backup"), dev);
                Map<String, Object> dlpsys = dlpscanMapper.getSystemsBydid(devid);
                SerializeUtil.serializeObj(new File(devDir, "systems.backup"), dlpsys);
                SerializeUtil.serializeObj(new File(devDir, "bug.backup"), dlpscanMapper.getResByTracker(ObjectUtil.getString(dlpsys.get("tracker"), "")));
                SerializeUtil.serializeObj(new File(devDir, "sta.backup"), dlpscanMapper.getDlpStaByDeviceid(devid));
            }
            ComonZipUtil.zip(dir.getPath(), f.getPath());
            if (dir != null && dir.exists()) {
                FileUtils.deleteDirectory(dir);
            }
            return f;
        } catch (Exception e) {
            throw e;
        }
    }

    @Transactional
    public void restore(HttpSession session, File f) throws Exception {
        File unzipFile = new File(Constant.COMMON_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
        ComonZipUtil.unzip(f, unzipFile);
        File taskFile = new File(unzipFile, "task.backup");
        Task t = (Task) SerializeUtil.deserializeObj(taskFile);
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = dlpscanMapper.getTaskCountByName(t.getName(), 9, uid, (Integer) null);
        if (count != null && count.intValue() > 0) {
            throw new UEException("dlpscanTaskAlready:" + unzipFile.getName());
        }
        try {
            exeRestore(unzipFile, t);
        } catch (Exception e) {
            FileUtils.deleteDirectory(unzipFile);
            throw e;
        }
    }

    private void exeRestore(File unzipFile, Task t) throws Exception {
        Map<String, Object> device;
        Map<String, Object> systems;
        if (unzipFile == null || t == null) {
            return;
        }
        dlpscanMapper.insert(t);
        for (File taskDir : unzipFile.listFiles()) {
            if (!taskDir.getName().equals("task.backup") && (device = (Map) SerializeUtil.deserializeObj(new File(taskDir, "dev.backup"))) != null && device.size() != 0 && (systems = (Map) SerializeUtil.deserializeObj(new File(taskDir, "systems.backup"))) != null && systems.size() != 0) {
                device.put("taskId", t.getId());
                dlpscanMapper.inserTaskDevById(device);
                systems.put("taskid", t.getId());
                systems.put("deviceid", ObjectUtil.getInt(device.get("id")));
                dlpscanMapper.insertDlpMap(systems);
                List<Map<String, Object>> bugs = (List) SerializeUtil.deserializeObj(new File(taskDir, "bug.backup"));
                if (bugs != null && bugs.size() > 0) {
                    dlpscanMapper.insertResults(ObjectUtil.getString(systems.get("tracker"), ""), bugs);
                }
                List<Map<String, Object>> sta = (List) SerializeUtil.deserializeObj(new File(taskDir, "sta.backup"));
                if (sta != null && sta.size() > 0) {
                    dlpscanMapper.insertSta(ObjectUtil.getInt(device.get("id")), sta);
                }
            }
        }
        startTimer(t.getId(), t.getType(), t.getPeriodTime(), t.getAlarmType(), t.getAlarmMethod(), t.getAlarmTime());
        FileUtils.deleteDirectory(unzipFile);
    }

    public void enter(HttpSession session, String filename) throws Exception {
        File f = new File(Constant.COMMON_DIR, filename);
        if (f == null || !f.exists()) {
            LOG.error("敏感信息扫描恢复，文件不存在！");
            return;
        }
        User u = (User) session.getAttribute("userInfo");
        Task t = (Task) SerializeUtil.deserializeObj(new File(f, "task.backup"));
        t.setName(String.valueOf(t.getName()) + System.nanoTime());
        t.setUid(u.getId());
        try {
            exeRestore(f, t);
        } catch (Exception e) {
            FileUtils.deleteDirectory(f);
            throw e;
        }
    }

    public Map<String, Object> getSystemsBydid(Integer id) throws Exception {
        return dlpscanMapper.getSystemsBydid(id);
    }

    public List<Map<String, Object>> bugForDevice(Integer id) throws Exception {
        return dlpscanMapper.bugForDevice(id);
    }

    public List<Map<String, Object>> bugPie(Integer id) {
        return dlpscanMapper.bugPie(id);
    }

    public int insertResults(String tracker, List<Map<String, Object>> list) throws Exception {
        return dlpscanMapper.insertResults(tracker, list);
    }

    public int insertSta(Integer deviceid, List<Map<String, Object>> list) throws Exception {
        return dlpscanMapper.insertSta(deviceid, list);
    }

    public int delResByTracker(String tracker) throws Exception {
        return dlpscanMapper.delResByTracker(tracker);
    }

    private void delDlpRes(String tracker) throws Exception {
        dlpscanMapper.delResByTracker(tracker);
        dlpscanMapper.delAgentByTracker(tracker);
        dlpscanMapper.delAgentCountByTracker(tracker);
        dlpscanMapper.delAgentZipByTracker(tracker);
    }

    public int delDlpBydevid(Integer deviceid) throws Exception {
        return delDlpBydevid(deviceid);
    }

    public List<Map<String, Object>> getStructTreeByDevid(Integer id) throws Exception {
        return dlpscanMapper.getStructTreeByDevid(id);
    }

    /* JADX WARN: Type inference failed for: r0v0, types: [com.datacloudsec.scan.service.impl.DlpscanService$2] */
    public static void main(String[] args) throws Exception {
        new Thread() { // from class: com.datacloudsec.scan.service.impl.DlpscanService.2
            @Override // java.lang.Thread, java.lang.Runnable
            public void run() {
                try {
                    AbsDlpDb db = AbsDlpDb.createDb("104", "192.168.0.219", 11211, "admin", "123456", 0, 0, false);
                    String[] keywords = {"日本", "女优", "AV"};
                    String[] regx = {"[0-9]{11}", "\\w+([-+.]\\w+)*@\\w+([-.]\\w+)*\\.\\w+([-.]\\w+)*"};
                    new Engine(new ConsoleHandler(), keywords, regx).scan(db, "".split("\n"), 0, "".split("\n"), 0, "".split("\n"));
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        }.start();
    }

    /* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/DlpscanService$DlpscanHandler.class */
    private static class DlpscanHandler implements IHandler {
        private Map<String, Object> device;
        private int id;
        private String tracker;
        private int dlpCount;
        private Set<String> dbSet = new HashSet();
        private int tableCount = 0;
        private int colCount = 0;

        public DlpscanHandler(Map<String, Object> device, String tracker) {
            this.device = device;
            this.tracker = tracker;
            if (device != null) {
                this.id = ObjectUtil.getInt(device.get("id")).intValue();
            }
        }

        public void init(AbsDlpDb db, Map<String, List<String>> tables) {
            if (tables != null) {
                int tableTotal = 0;
                for (Map.Entry<String, List<String>> entry : tables.entrySet()) {
                    tableTotal += entry.getValue().size();
                }
                try {
                    DlpscanService.dlpscanMapper.updDbDlp(Integer.valueOf(this.id), 1, Integer.valueOf(tables.size()), Integer.valueOf(tableTotal), (Integer) null, (Integer) null, (Integer) null, JsonUtil.MAPPER.writeValueAsString(tables));
                } catch (Exception e) {
                    DlpscanService.LOG.error("", e);
                }
            }
        }

        public void error(AbsDlpDb arg0, String errorText, Exception e, boolean isEnd) {
            if (StringUtils.isBlank(errorText) && e != null) {
                errorText = e.getMessage();
            }
            if (isEnd) {
                try {
                    DlpscanService.engMapper.updateScanInfo(Integer.valueOf(this.id), 3, (Double) null, (Integer) null, (Integer) null, errorText, (Integer) null, (Integer) null, (Integer) null, (Date) null, false);
                    DlpscanService.LOG.error("", e);
                } catch (Exception e1) {
                    DlpscanService.LOG.error("", e1);
                }
            }
        }

        public void finish(AbsDlpDb db) {
            try {
                DlpscanService.engMapper.updateDlpInfo(Integer.valueOf(this.id), 2, Float.valueOf(100.0f), new Date(), (String) null, (String) null);
                DlpscanService.dlpscanMapper.insertDlpSta(Integer.valueOf(this.id), Integer.valueOf(this.dlpCount), new Date());
                Task task = DlpscanService.dlpscanMapper.getTaskById(ObjectUtil.getInt(this.device.get("taskId")));
                FtpUtil.reportUpload(task, this.device, (String) IReport.REPORT_CHK.get("db"), "db");
                if (ObjectUtil.getInt(this.device.get("alarmType"), 0) == 1) {
                    AlermJob.alermDevice(this.device);
                }
            } catch (Exception e) {
                DlpscanService.LOG.error("", e);
            }
        }

        public void result(AbsDlpDb db, String dbname, String tablename, String clumnname, long num, Set<String> keys) {
            DlpscanService.dlpscanMapper.insertDbResult("", ObjectUtil.getString(this.device.get("ip"), ""), this.tracker, dbname, tablename, new StringBuilder(String.valueOf(num)).toString(), clumnname, StringUtils.join(keys, ","));
            this.dlpCount++;
        }

        public void start(AbsDlpDb arg0) {
            Map<String, Object> taskwebmap = new HashMap<>();
            taskwebmap.put("devid", Integer.valueOf(this.id));
            taskwebmap.put("status", 1);
            taskwebmap.put("scanCount", Integer.valueOf(ObjectUtil.getInt(this.device.get("scanCount"), 0) + 1));
            taskwebmap.put("progress", 0);
            taskwebmap.put("startTime", new Date());
            DlpscanService.dlpscanMapper.updateTaskDevice(taskwebmap);
            DlpscanService.dlpscanMapper.delResByTracker(this.tracker);
            DlpscanService.dlpscanMapper.updDbDlp(Integer.valueOf(this.id), 1, 0, 0, 0, 0, 0, (String) null);
        }

        public void progress(AbsDlpDb db, String dbname, String table, Integer rows, Integer cols, int progress) {
            if (StringUtils.isNotBlank(dbname) && StringUtils.isNotBlank(table)) {
                this.dbSet.add(dbname);
                String exeInfo = "{\"db\":\"" + dbname + "\",\"table\":\"" + table + "\",\"rows\":\"" + rows + "\",\"cols\":\"" + cols + "\"}";
                DlpscanMapper dlpscanMapper = DlpscanService.dlpscanMapper;
                Integer valueOf = Integer.valueOf(this.id);
                Integer valueOf2 = Integer.valueOf(this.dbSet.size());
                int i = this.tableCount + 1;
                this.tableCount = i;
                Integer valueOf3 = Integer.valueOf(i);
                int intValue = this.colCount + cols.intValue();
                this.colCount = intValue;
                dlpscanMapper.updDbDlp(valueOf, 1, (Integer) null, (Integer) null, valueOf2, valueOf3, Integer.valueOf(intValue), (String) null);
                DlpscanService.engMapper.updateDlpInfo(Integer.valueOf(this.id), 1, Float.valueOf(ObjectUtil.getFloat(Integer.valueOf(progress), 0.0f)), new Date(), exeInfo, (String) null);
            }
        }
    }
}
